summaryrefslogtreecommitdiff
path: root/gtk2_ardour/port_matrix_component.h
diff options
context:
space:
mode:
Diffstat (limited to 'gtk2_ardour/port_matrix_component.h')
-rw-r--r--gtk2_ardour/port_matrix_component.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/gtk2_ardour/port_matrix_component.h b/gtk2_ardour/port_matrix_component.h
index 39ea6b3c0d..9eb2c566a5 100644
--- a/gtk2_ardour/port_matrix_component.h
+++ b/gtk2_ardour/port_matrix_component.h
@@ -141,8 +141,8 @@ protected:
return Gdk::Color ("#ff0000");
}
- /** @return colour to paint mouseover lines */
- static Gdk::Color mouseover_port_colour () {
+ /** @return colour to paint channel highlights */
+ static Gdk::Color highlighted_channel_colour () {
return Gdk::Color ("#777777");
}